var rp = require("request-promise");

function API(config) {
    this.config = config;
}

/**
 * Retrieves all Receipts yet to be sent to SAP
 *
 * @returns {Promise} Pending API service response
 */
API.prototype.getReceipts = function() {
    var url = this.config.receipts.api;
    var options = {
        uri: url + "/api/v1/receipts/SAP",
        method: 'GET',
        headers: {
            'User-Agent': 'fmc (node/' + process.version + ')',
            'Content-Type': 'application/json'
        },
        json: true,
        resolveWithFullResponse: true
    };
    return rp(options).promise();
};

/**
 * PUTs Receipt data to update the sap flags
 *
 * @param ids Database keys to update
 * @returns {Promise} Pending API service response
 */
API.prototype.updateReceipts = function(ids) {

    if (ids) {
        var url = this.config.receipts.api;
        var options = {
            uri: url + "/api/v1/receipts/SAP",
            method: 'PUT',
            headers: {
                'User-Agent': 'fmc (node/' + process.version + ')',
                'Content-Type': 'application/json'
            },
            body: ids,
            json: true,
            resolveWithFullResponse: true
        };
        return rp(options).promise();
    }
    return null;
};
/**
 * Sends test Receipt data to the API server
 *
 * @param receipts
 * @param endpoint
 * @returns {Promise} Pending API service response
 */
API.prototype.saveReceipts = function(receipts, endpoint) {
    var self = this;
    var lines = receipts;
    var apiEP = self.config.perf.api;
    if (endpoint && (endpoint.indexOf("3414") > 0 || endpoint.indexOf("3415") > 0)) {
        apiEP = endpoint;
    }
    var options = {
        uri: (apiEP.includes("/api") ? apiEP : apiEP + "/api/saveInventoryData"),
        method: 'POST',
        headers: {
            'User-Agent': 'fmc (node/' + process.version + ')',
            'Content-Type': 'application/json'
        },
        body: lines,
        json: true,
        resolveWithFullResponse: true
    };
    return rp(options).promise();
};

/**
 * Retrieves all clinics from the db via API.  Will be used to randomize which clinics push data
 *
 * @param {String} endpoint original URL for the task... to determine host if diff from default
 * @returns {Promise} API POST promise that will get the data
 */
API.prototype.getClinics = function(endpoint) {
    var apiEP = this.config.perf.api;
    if (endpoint && (endpoint.indexOf("3414") > 0 || endpoint.indexOf("3415") > 0)) {
        apiEP = endpoint;
    }
    var options = {
        uri: (apiEP.includes("/api") ? apiEP.substring(0, apiEP.indexOf("/api")) : apiEP) + "/api/getClinicProfile",
        method: 'POST',
        headers: {
            'User-Agent': 'fmc (node/' + process.version + ')',
            'Content-Type': 'application/json'
        },
        json: true,
        resolveWithFullResponse: true
    };
    return rp(options).promise();

};

/**
 * Retrieves all active items from the db via API.  Will be used to randomize which line items pushed
 *
 * @param {String} endpoint original URL for the task... to determine host if diff from default
 * @returns {Promise} API POST promise that will get the data
 */
API.prototype.getItems = function(endpoint) {
    var apiEP = this.config.perf.api;
    if (endpoint && (endpoint.indexOf("3414") > 0 || endpoint.indexOf("3415") > 0)) {
        apiEP = endpoint;
    }
    var options = {
        uri: (apiEP.includes("/api") ? apiEP.substring(0, apiEP.indexOf("/api")) : apiEP) + "/api/v2/getMasterItem",
        method: 'POST',
        headers: {
            'User-Agent': 'fmc (node/' + process.version + ')',
            'Content-Type': 'application/json'
        },
        json: true,
        resolveWithFullResponse: true
    };
    return rp(options).promise();

};

module.exports = API;