/**
 * Created by John on 7/3/2017.
 */
var path = require('path');
var config = require(path.join(__dirname,  '..', '/components/config/server.test.js'));
var expect = require('chai').expect;
var moment = require('moment');
var _ = require("lodash");
var JwtHelper = require("../components/helpers/JwtHelper");
var AsnHelper = require("../components/helpers/AsnHelper");
var uuid = require("uuid");



describe("Fresenius Integration", function() {

    it('should place multiple message on the queue via API', function (done) {
        var MQSHelper;
        var helper;
        if (config.mqs && config.mqs === "rabbit") {
            //must setup queue subscriber before publisher
            var rabbit = require("rabbot");
            MQSHelper = require("../components/helpers/RabbitHelper");
            helper = new MQSHelper(null, config);
            require("./RabbitSubscriberTest")(rabbit, config, function (err, msgCount) {
                expect(err).to.be.null;
                expect(msgCount).to.be.greaterThan(0);
                if (msgCount === 5) {
                    rabbit.shutdown();
                    done();
                }
            });
        } else if (config.mqs && config.mqs === "sqs") {

            //must setup queue subscriber before publisher
            MQSHelper = require("../components/helpers/SqsHelper");
            helper = new MQSHelper(null, config);

            var cleanup = function(done) {
                helper.cleanUp();
                done();
            };

            require("./SQSSubscriberTest")(helper, function (err, msgCount) {
                expect(err).to.be.null;
                expect(msgCount).to.be.greaterThan(0);
                if (msgCount === 5) {
                    setTimeout(cleanup, 500, done);
                }
            });
        } else {
            MQSHelper = require("../components/helpers/NullMqsHelper");
            helper = new MQSHelper();
            var Tail = require("tail").Tail;
            var options= {separator: /[\r]{0,1}\n/, fromBeginning: false, fsWatchOptions: {}, follow: true, logger: console};
            var tail = new Tail(helper.getFilename(), options);
            tail.on("line", function(data) {
                expect(data).to.not.be.null;
                if (data.startsWith("},")) {
                    tail.unwatch();
                    done();
                }
            });
            tail.on("error", function(error) {
                expect(error).to.not.be.null;
                tail.unwatch();
                done();
            });
        }
        //set up API listening
        var express = require('express');
        var app = express();
        var port = process.env.PORT || 8080;
        app.listen(port, '0.0.0.0');
        app.set("mqs", helper);
        require('../components/config/express')(app, config);
        //setup a new password for the API
        var newUUID = "" + uuid.v4({rng: uuid.mathRNG});
        newUUID = newUUID.replace(/\-/g, "");
        var jwthelper = new JwtHelper(config);
        jwthelper.addUser("api", newUUID);
        var asnhelper = new AsnHelper();
        //generate multi-lines after allowing Rabbit to init
        setTimeout(asnhelper.publishViaApi.bind(asnhelper), 3000, "api", newUUID, function (err, response) {
            expect(err).to.be.null;
            expect(response).to.not.be.null;
            expect(response.body).to.equal("OK");
        });

    }).timeout(15000);


});